@@ -9,6 +9,8 @@ class GraphqlValueMapper:
     A class to map GraphQL values to DeviceReading instances.
     """
 
+    OnState = "on"
+
     def map_query_values(self, values: Dict[str, Any]) -> list[Dict[str, Any]]:
         readings: list[Dict[str, Any]] = []
         for device in values:
@@ -57,6 +59,8 @@ class GraphqlValueMapper:
                 attributes.extend(self._build_gateway(device))
             case "colorbulb":
                 attributes.extend(self._build_light(device))
+            case "whitebulb":
+                attributes.extend(self._build_light(device))
             case "dimmer":
                 attributes.extend(self._build_dimmer(device))
             case "switch":
@@ -354,6 +358,11 @@ class GraphqlValueMapper:
             attributes.append(
                 self.build_attribute(device["hiloId"], "CcrMode", device["ccrMode"])
             )
+        attributes.append(
+            self.build_attribute(
+                device["hiloId"], "OnOff", device["state"].lower() == self.OnState
+            )
+        )
         return attributes
 
     def _build_charging_point(self, device: Dict[str, Any]) -> list[Dict[str, Any]]:
@@ -372,10 +381,14 @@ class GraphqlValueMapper:
         if device.get("power") is not None:
             attributes.append(self._map_power(device))
         attributes.append(
-            self.build_attribute(device["hiloId"], "Status", device["state"])
+            self.build_attribute(
+                device["hiloId"], "Status", device["state"].lower() == self.OnState
+            )
         )
         attributes.append(
-            self.build_attribute(device["hiloId"], "OnOff", device["state"])
+            self.build_attribute(
+                device["hiloId"], "OnOff", device["state"].lower() == self.OnState
+            )
         )
         return attributes
 
@@ -390,7 +403,9 @@ class GraphqlValueMapper:
                 )
             )
         attributes.append(
-            self.build_attribute(device["hiloId"], "OnOff", device["state"])
+            self.build_attribute(
+                device["hiloId"], "OnOff", device["state"].lower() == self.OnState
+            )
         )
         return attributes
 
@@ -420,7 +435,9 @@ class GraphqlValueMapper:
                 )
             )
         attributes.append(
-            self.build_attribute(device["hiloId"], "OnOff", device["state"])
+            self.build_attribute(
+                device["hiloId"], "OnOff", device["state"].lower() == self.OnState
+            )
         )
         return attributes
 
